@@ -2,9 +2,11 @@ package App::Jawk;
 use strict;
 
 BEGIN {
-$VERSION = '0.09';
+our $VERSION = '0.10';
 };
 
+1;
+
 # this is just here for the documentation
 
 =head1 NAME
